@@ -533,14 +533,14 @@ brasero_burn_dialog_get_media_type_string (BraseroBurn *burn,
 
 		if ((type & BRASERO_MEDIUM_CD) && !(type & BRASERO_MEDIUM_DVD)) {
 			if (!insert) {
-				if (isosize)
+				if (isosize > 0)
 					message = g_strdup_printf (_("Please replace the disc with a writable CD with at least %i MiB of free space."), 
 								   (int) (isosize / 1048576));
 				else
 					message = g_strdup (_("Please replace the disc with a writable CD."));
 			}
 			else {
-				if (isosize)
+				if (isosize > 0)
 					message = g_strdup_printf (_("Please insert a writable CD with at least %i MiB of free space."), 
 								   (int) (isosize / 1048576));
 				else
@@ -549,14 +549,14 @@ brasero_burn_dialog_get_media_type_string (BraseroBurn *burn,
 		}
 		else if (!(type & BRASERO_MEDIUM_CD) && (type & BRASERO_MEDIUM_DVD)) {
 			if (!insert) {
-				if (isosize)
+				if (isosize > 0)
 					message = g_strdup_printf (_("Please replace the disc with a writable DVD with at least %i MiB of free space."), 
 								   (int) (isosize / 1048576));
 				else
 					message = g_strdup (_("Please replace the disc with a writable DVD."));
 			}
 			else {
-				if (isosize)
+				if (isosize > 0)
 					message = g_strdup_printf (_("Please insert a writable DVD with at least %i MiB of free space."), 
 								   (int) (isosize / 1048576));
 				else
@@ -1050,7 +1050,7 @@ brasero_burn_dialog_disable_joliet_cb (BraseroBurn *burn,
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
 
-	if (!GTK_WIDGET_VISIBLE (dialog)) {
+	if (!gtk_widget_get_visible (GTK_WIDGET (dialog))) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		hide = TRUE;
 	}
@@ -1308,7 +1308,7 @@ brasero_burn_dialog_dummy_success_cb (BraseroBurn *burn,
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
 
-	if (!GTK_WIDGET_MAPPED (dialog)) {
+	if (!gtk_widget_get_mapped (GTK_WIDGET (dialog))) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		hide = TRUE;
 	} else
@@ -1609,6 +1609,7 @@ brasero_burn_dialog_setup_session (BraseroBurnDialog *dialog,
 static void
 brasero_burn_dialog_save_log (BraseroBurnDialog *dialog)
 {
+	GError *error;
 	gchar *contents;
 	gchar *path = NULL;
 	GtkWidget *chooser;
@@ -1650,10 +1651,17 @@ brasero_burn_dialog_save_log (BraseroBurnDialog *dialog)
 		return;
 	}
 
-	g_file_get_contents (brasero_burn_session_get_log_path (priv->session),
-			     &contents,
-			     NULL,
-			     NULL);
+	error = NULL;
+	if (!g_file_get_contents (brasero_burn_session_get_log_path (priv->session),
+	                          &contents,
+	                          NULL,
+	                          &error)) {
+		g_warning ("Error while saving log file: %s\n", error? error->message:"none");
+		g_error_free (error);
+		g_free (path);
+		return;
+	}
+	
 	g_file_set_contents (path, contents, -1, NULL);
 
 	g_free (contents);
@@ -1828,10 +1836,10 @@ brasero_burn_dialog_notify_copy_finished (BraseroBurnDialog *dialog,
 
 	brasero_burn_dialog_update_session_info (dialog);
 
-	if (!GTK_WIDGET_VISIBLE (dialog))
+	if (!gtk_widget_get_visible (GTK_WIDGET (dialog)))
 		gtk_widget_show (GTK_WIDGET (dialog));
 
-	main_message = g_strdup_printf (_("Copy #%i has been burned successfully."), ++ priv->num_copies);
+	main_message = g_strdup_printf (_("Copy #%i has been burned successfully."), priv->num_copies ++);
 	message = brasero_burn_dialog_create_message (dialog,
 	                                              GTK_MESSAGE_INFO,
 	                                              GTK_BUTTONS_CANCEL,
@@ -1876,7 +1884,12 @@ brasero_burn_dialog_success_run (BraseroBurnDialog *dialog)
 		GtkWidget *window;
 
 		window = brasero_session_edit_cover (priv->session, GTK_WIDGET (dialog));
-		gtk_dialog_run (GTK_DIALOG (window));
+		/* This strange hack is a way to workaround #568358.
+		 * At one point we'll need to hide the dialog which means it
+		 * will anwer with a GTK_RESPONSE_NONE */
+		while (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_NONE)
+			gtk_widget_show (GTK_WIDGET (dialog));
+
 		gtk_widget_destroy (window);
 		return FALSE;
 	}
@@ -1902,8 +1915,8 @@ brasero_burn_dialog_notify_success (BraseroBurnDialog *dialog)
 	 * - we wrote a merged session
 	 * - we were not already asked for a series of copy */
 	if (!priv->num_copies
-	&& !brasero_burn_session_is_dest_file (priv->session)
-	&&!(brasero_burn_session_get_flags (priv->session) & BRASERO_BURN_FLAG_MERGE)) {
+	&&  !brasero_burn_session_is_dest_file (priv->session)
+	&& !(brasero_burn_session_get_flags (priv->session) & BRASERO_BURN_FLAG_MERGE)) {
 		/* Useful button but it shouldn't be used for images */
 		make_another = gtk_dialog_add_button (GTK_DIALOG (dialog),
 						      _("Make _More Copies"),
@@ -2021,9 +2034,11 @@ brasero_burn_dialog_end_session (BraseroBurnDialog *dialog,
 	}
 	else if (priv->num_copies) {
 		retry = brasero_burn_dialog_notify_copy_finished (dialog, error);
+		if (!retry)
+			brasero_burn_dialog_notify_success (dialog);
 	}
 	else {
-		/* see if an image was created. If so, add it to GtkRecent */
+		/* see if an image was created. If so, add it to GtkRecent. */
 		if (brasero_burn_session_is_dest_file (priv->session)) {
 			GSList *tracks;
 
@@ -2037,7 +2052,7 @@ brasero_burn_dialog_end_session (BraseroBurnDialog *dialog,
 		}
 
 		retry = brasero_burn_dialog_notify_success (dialog);
-		priv->num_copies = retry;
+		priv->num_copies = retry * 2;
 	}
 
 	if (priv->burn) {
@@ -2269,18 +2284,9 @@ brasero_burn_dialog_wait_for_ready_state (BraseroBurnDialog *dialog)
 	return (result == BRASERO_BURN_OK);
 }
 
-/**
- * brasero_burn_dialog_run:
- * @dialog: a #BraseroBurnDialog
- * @session: a #BraseroBurnSession
- *
- * Start burning the contents of @session.
- *
- * Return value: a #gboolean. TRUE if the operation was successfully carried out, FALSE otherwise.
- **/
-gboolean
-brasero_burn_dialog_run (BraseroBurnDialog *dialog,
-			 BraseroBurnSession *session)
+static gboolean
+brasero_burn_dialog_run_real (BraseroBurnDialog *dialog,
+			      BraseroBurnSession *session)
 {
 	BraseroBurnResult result;
 	BraseroBurnDialogPrivate *priv;
@@ -2341,6 +2347,55 @@ brasero_burn_dialog_run (BraseroBurnDialog *dialog,
 	return (result == BRASERO_BURN_OK);
 }
 
+/**
+ * brasero_burn_dialog_run_multi:
+ * @dialog: a #BraseroBurnDialog
+ * @session: a #BraseroBurnSession
+ *
+ * Start burning the contents of @session. Once a disc is burnt, a dialog
+ * will be shown to the user and wait for a new insertion before starting to burn
+ * again.
+ *
+ * Return value: a #gboolean. TRUE if the operation was successfully carried out, FALSE otherwise.
+ **/
+gboolean
+brasero_burn_dialog_run_multi (BraseroBurnDialog *dialog,
+			       BraseroBurnSession *session)
+{
+	BraseroBurnResult result;
+	BraseroBurnDialogPrivate *priv;
+
+	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
+	priv->num_copies = 1;
+
+	result = brasero_burn_dialog_run_real (dialog, session);
+	return (result == BRASERO_BURN_OK);
+}
+
+
+/**
+ * brasero_burn_dialog_run:
+ * @dialog: a #BraseroBurnDialog
+ * @session: a #BraseroBurnSession
+ *
+ * Start burning the contents of @session.
+ *
+ * Return value: a #gboolean. TRUE if the operation was successfully carried out, FALSE otherwise.
+ **/
+gboolean
+brasero_burn_dialog_run (BraseroBurnDialog *dialog,
+			 BraseroBurnSession *session)
+{
+	BraseroBurnResult result;
+	BraseroBurnDialogPrivate *priv;
+
+	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
+	priv->num_copies = 0;
+
+	result = brasero_burn_dialog_run_real (dialog, session);
+	return (result == BRASERO_BURN_OK);
+}
+
 static gboolean
 brasero_burn_dialog_cancel_dialog (BraseroBurnDialog *toplevel)
 {
