@@ -270,6 +270,27 @@ brasero_utils_unregister_string (const gchar *string)
 	G_UNLOCK (stringsH);
 }
 
+GtkWidget *
+brasero_utils_properties_get_label (GtkWidget *properties)
+{
+	GList *children;
+	GList *iter;
+
+	children = gtk_container_get_children (GTK_CONTAINER (properties));
+	for (iter = children; iter; iter = iter->next) {
+		GtkWidget *widget;
+
+		widget = iter->data;
+		if (GTK_IS_LABEL (widget)) {
+			g_list_free (children);
+			return widget;
+		}
+	}
+
+	g_list_free (children);
+	return NULL;
+}
+
 GtkWidget *
 brasero_utils_pack_properties_list (const gchar *title, GSList *list)
 {
@@ -388,15 +409,14 @@ brasero_utils_create_message_dialog (GtkWidget *parent,
 	GtkWidget *message;
 
 	message = gtk_message_dialog_new (GTK_WINDOW (parent),
-					  GTK_DIALOG_MODAL |
-					  GTK_DIALOG_DESTROY_WITH_PARENT,
+					  0,
 					  type,
 					  GTK_BUTTONS_CLOSE,
 					  "%s",
 					  primary_message);
 
 	gtk_window_set_icon_name (GTK_WINDOW (message),
-	                          gtk_window_get_icon_name (GTK_WINDOW (parent)));
+	                          parent? gtk_window_get_icon_name (GTK_WINDOW (parent)):"brasero");
 
 	gtk_window_set_title (GTK_WINDOW (message), "");
 
