@@ -271,6 +271,33 @@ brasero_wodim_compute (BraseroWodim *wodim,
 	}
 }
 
+static void
+brasero_wodim_set_rate (BraseroProcess *process,
+                        int speed_1,
+                        int speed_2)
+{
+	gdouble current_rate = -1.0;
+	BraseroMedia media;
+
+	if (brasero_job_get_media (BRASERO_JOB (process), &media) != BRASERO_BURN_OK)
+		return;
+
+	if (BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_CD))
+		current_rate = (gdouble) ((gdouble) speed_1 +
+			       (gdouble) speed_2 / 10.0) *
+			       (gdouble) CD_RATE;
+	else if (BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_DVD))
+		current_rate = (gdouble) ((gdouble) speed_1 +
+			       (gdouble) speed_2 / 10.0) *
+			       (gdouble) DVD_RATE;
+	else if (BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_BD))
+		current_rate = (gdouble) ((gdouble) speed_1 +
+			       (gdouble) speed_2 / 10.0) *
+			       (gdouble) BD_RATE;
+
+	brasero_job_set_rate (BRASERO_JOB (process), current_rate);
+}
+
 static BraseroBurnResult
 brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 {
@@ -284,14 +311,11 @@ brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 	priv = BRASERO_WODIM_PRIVATE (wodim);
 
 	if (sscanf (line, "Track %2u: %d of %d MB written (fifo %d%%) [buf %d%%] %d.%dx.",
-		    &track, &mb_written, &mb_total, &fifo, &buf, &speed_1, &speed_2) == 7) {
-		gdouble current_rate;
-
-		current_rate = (gdouble) ((gdouble) speed_1 +
-			       (gdouble) speed_2 / 10.0) *
-			       (gdouble) CD_RATE;
-		brasero_job_set_rate (BRASERO_JOB (wodim), current_rate);
-
+		    &track, &mb_written, &mb_total, &fifo, &buf, &speed_1, &speed_2) == 7 ||
+	    /* This is for DVD+R */
+	    sscanf (line, "Track %2u:    %d of %d MB written (fifo  %d%%) [buf  %d%%] |%*s  %*s|   %d.%dx.",
+	            &track, &mb_written, &mb_total, &fifo, &buf, &speed_1, &speed_2) == 7) {
+		brasero_wodim_set_rate (process, speed_1, speed_2);
 		priv->current_track_written = (goffset) mb_written * (goffset) 1048576LL;
 		brasero_wodim_compute (wodim,
 				       mb_written,
@@ -301,15 +325,11 @@ brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 		brasero_job_start_progress (BRASERO_JOB (wodim), FALSE);
 	} 
 	else if (sscanf (line, "Track %2u:    %d MB written (fifo %d%%) [buf  %d%%]  %d.%dx.",
+			 &track, &mb_written, &fifo, &buf, &speed_1, &speed_2) == 6 ||
+	         sscanf (line, "Track %2u:    %d MB written (fifo %d%%) [buf  %d%%] |%*s  %*s|   %d.%dx.",
 			 &track, &mb_written, &fifo, &buf, &speed_1, &speed_2) == 6) {
-		gdouble current_rate;
-
 		/* this line is printed when wodim writes on the fly */
-		current_rate = (gdouble) ((gdouble) speed_1 +
-			       (gdouble) speed_2 / 10.0) *
-			       (gdouble) CD_RATE;
-		brasero_job_set_rate (BRASERO_JOB (wodim), current_rate);
-
+		brasero_wodim_set_rate (process, speed_1, speed_2);
 		priv->current_track_written = (goffset) mb_written * (goffset) 1048576LL;
 		if (brasero_job_get_fd_in (BRASERO_JOB (wodim), NULL) == BRASERO_BURN_OK) {
 			goffset bytes = 0;
@@ -864,7 +884,6 @@ brasero_wodim_set_argv_record (BraseroWodim *wodim,
 			/* NOTE: when we don't want wodim to use stdin then we
 			 * give the audio file on the command line. Otherwise we
 			 * use the .inf */
-			g_ptr_array_add (argv, g_strdup ("-swab"));
 			g_ptr_array_add (argv, g_strdup ("-audio"));
 			g_ptr_array_add (argv, g_strdup ("-useinfo"));
 			g_ptr_array_add (argv, g_strdup ("-text"));
@@ -888,7 +907,6 @@ brasero_wodim_set_argv_record (BraseroWodim *wodim,
 
 		g_ptr_array_add (argv, g_strdup ("fs=16m"));
 		g_ptr_array_add (argv, g_strdup ("-audio"));
-		g_ptr_array_add (argv, g_strdup ("-swab"));
 		g_ptr_array_add (argv, g_strdup ("-pad"));
 	
 		g_ptr_array_add (argv, g_strdup ("-useinfo"));
@@ -968,6 +986,7 @@ brasero_wodim_set_argv_record (BraseroWodim *wodim,
 		else if (format == BRASERO_IMAGE_FORMAT_CUE) {
 			gchar *cue_str;
 			gchar *cuepath;
+			gchar *parent;
 
 			cuepath = brasero_track_image_get_toc_source (BRASERO_TRACK_IMAGE (track), FALSE);
 			if (!cuepath) {
@@ -975,8 +994,19 @@ brasero_wodim_set_argv_record (BraseroWodim *wodim,
 				BRASERO_JOB_NOT_READY (wodim);
 			}
 
+			parent = g_path_get_dirname (cuepath);
+			brasero_process_set_working_directory (BRASERO_PROCESS (wodim), parent);
+			g_free (parent);
+
+			/* we need to check endianness */
+			if (brasero_track_image_need_byte_swap (BRASERO_TRACK_IMAGE (track)))
+				g_ptr_array_add (argv, g_strdup ("-swab"));
+
 			g_ptr_array_add (argv, g_strdup ("fs=16m"));
 
+			/* This is to make sure the CD-TEXT stuff gets written */
+			g_ptr_array_add (argv, g_strdup ("-text"));
+
 			cue_str = g_strdup_printf ("cuefile=%s", cuepath);
 			g_ptr_array_add (argv, cue_str);
 			g_free (cuepath);
