@@ -239,7 +239,7 @@ brasero_audio_disc_is_empty (BraseroDisc *disc)
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (BRASERO_AUDIO_DISC (disc)->priv->tree));
 	if (!model)
-		return TRUE;
+		return FALSE;
 
 	return gtk_tree_model_iter_n_children (model, NULL) != 0;
 }
@@ -418,12 +418,12 @@ brasero_audio_disc_init (BraseroAudioDisc *obj)
 							   "text", BRASERO_VIDEO_TREE_MODEL_INDEX,
 							   NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree), column);
-	gtk_tree_view_column_set_resizable (column, FALSE);
+	gtk_tree_view_column_set_resizable (column, TRUE);
 
 	/* Other columns */
 	column = gtk_tree_view_column_new ();
 	gtk_tree_view_column_set_resizable (column, TRUE);
-	gtk_tree_view_column_set_min_width (column, 200);
+	gtk_tree_view_column_set_expand (column, TRUE);
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_tree_view_column_pack_start (column, renderer, FALSE);
@@ -456,14 +456,10 @@ brasero_audio_disc_init (BraseroAudioDisc *obj)
 					    "editable", BRASERO_VIDEO_TREE_MODEL_EDITABLE);
 	gtk_tree_view_column_set_title (column, _("Title"));
 	g_object_set (G_OBJECT (column),
-		      "expand", TRUE,
 		      "spacing", 4,
 		      NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree),
-				     column);
-
-	gtk_tree_view_set_expander_column (GTK_TREE_VIEW (obj->priv->tree),
-					   column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree), column);
+	gtk_tree_view_set_expander_column (GTK_TREE_VIEW (obj->priv->tree), column);
 
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set_data (G_OBJECT (renderer), COL_KEY, BRASERO_TRACK_STREAM_ARTIST_TAG);
@@ -483,8 +479,7 @@ brasero_audio_disc_init (BraseroAudioDisc *obj)
 	column = gtk_tree_view_column_new_with_attributes (_("Artist"), renderer,
 							   "text", BRASERO_VIDEO_TREE_MODEL_ARTIST,
 							   NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree),
-				     column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree), column);
 	gtk_tree_view_column_set_resizable (column, TRUE);
 	gtk_tree_view_column_set_min_width (column, 200);
 
@@ -493,9 +488,8 @@ brasero_audio_disc_init (BraseroAudioDisc *obj)
 							   "text", BRASERO_VIDEO_TREE_MODEL_SIZE,
 							  /* "background", BACKGROUND_COL, */
 							   NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree),
-				     column);
-	gtk_tree_view_column_set_resizable (column, FALSE);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree), column);
+	gtk_tree_view_column_set_resizable (column, TRUE);
 
 	scroll = gtk_scrolled_window_new (NULL, NULL);
 	gtk_widget_show (scroll);
@@ -1831,8 +1825,14 @@ brasero_audio_disc_button_pressed_cb (GtkTreeView *tree,
 {
 	GtkWidgetClass *widget_class;
 
+	/* Avoid minding signals that happen out of the tree area (like in the 
+	 * headers for example) */
+	if (event->window != gtk_tree_view_get_bin_window (GTK_TREE_VIEW (tree)))
+		return FALSE;
+
 	widget_class = GTK_WIDGET_GET_CLASS (tree);
 
+	/* Check that the click happened in the main window with rows. */
 	if (event->button == 3) {
 		GtkTreeSelection *selection;
 		GtkTreePath *path = NULL;
@@ -1896,7 +1896,7 @@ brasero_audio_disc_button_pressed_cb (GtkTreeView *tree,
 		 * so it can update itself (paticularly its selection) before we have
 		 * a look at it */
 		widget_class->button_press_event (GTK_WIDGET (tree), event);
-		
+
 		if (!treepath) {
 			GtkTreeSelection *selection;
 
@@ -1907,7 +1907,7 @@ brasero_audio_disc_button_pressed_cb (GtkTreeView *tree,
 			gtk_tree_selection_unselect_all (selection);
 			return FALSE;
 		}
-	
+
 		if (!result)
 			return FALSE;
 
